summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJiří Klimeš <jklimes@redhat.com>2015-04-17 09:07:15 +0200
committerJiří Klimeš <jklimes@redhat.com>2015-04-20 09:45:57 +0200
commit8257940606b1ad3cd333974a0c5c52afd4281a8b (patch)
treea2563854b857aeee0ab809cb13bce6b2bf96cbe5
parentec47b9624e2d2fc9ccb09ced96c5b7e720def563 (diff)
downloadNetworkManager-8257940606b1ad3cd333974a0c5c52afd4281a8b.tar.gz
core: (trivial) fix spelling in comments
-rw-r--r--src/devices/nm-device.c8
-rw-r--r--src/nm-default-route-manager.c8
-rw-r--r--src/nm-policy.c2
3 files changed, 9 insertions, 9 deletions
diff --git a/src/devices/nm-device.c b/src/devices/nm-device.c
index 4658cd0fd5..85050154d3 100644
--- a/src/devices/nm-device.c
+++ b/src/devices/nm-device.c
@@ -6819,8 +6819,8 @@ update_ip_config (NMDevice *self, gboolean initial)
ensure_con_ipx_config (self);
/* This function was called upon external changes. Remove the configuration
- * (adresses,routes) that is no longer present externally from the interal
- * config. This way, we don't readd addresses that were manually removed
+ * (addresses,routes) that is no longer present externally from the internal
+ * config. This way, we don't read addresses that were manually removed
* by the user. */
if (priv->con_ip4_config)
nm_ip4_config_intersect (priv->con_ip4_config, priv->ext_ip4_config);
@@ -6858,8 +6858,8 @@ update_ip_config (NMDevice *self, gboolean initial)
ensure_con_ipx_config (self);
/* This function was called upon external changes. Remove the configuration
- * (adresses,routes) that is no longer present externally from the interal
- * config. This way, we don't readd addresses that were manually removed
+ * (addresses,routes) that is no longer present externally from the internal
+ * config. This way, we don't read addresses that were manually removed
* by the user. */
if (priv->con_ip6_config)
nm_ip6_config_intersect (priv->con_ip6_config, priv->ext_ip6_config);
diff --git a/src/nm-policy.c b/src/nm-policy.c
index d995421a33..69d12d7de0 100644
--- a/src/nm-policy.c
+++ b/src/nm-policy.c
@@ -170,7 +170,7 @@ _set_hostname (NMPolicy *policy,
* there was no valid hostname to start with.
*/
- /* Clear lookup adresses if we have a hostname, so that we don't
+ /* Clear lookup addresses if we have a hostname, so that we don't
* restart the reverse lookup thread later.
*/
if (new_hostname)
diff --git a/src/nm-default-route-manager.c b/src/nm-default-route-manager.c
index 65fb584c5a..ee377bcc7e 100644
--- a/src/nm-default-route-manager.c
+++ b/src/nm-default-route-manager.c
@@ -538,7 +538,7 @@ _resync_all (const VTableIP *vtable, NMDefaultRouteManager *self, const Entry *c
} else {
if (!_vt_routes_has_entry (vtable, routes, entry)) {
g_array_append_val (changed_metrics, entry->effective_metric);
- _LOGD (vtable->vt->addr_family, LOG_ENTRY_FMT": readd route %s (%u -> %u)", LOG_ENTRY_ARGS (i, entry),
+ _LOGD (vtable->vt->addr_family, LOG_ENTRY_FMT": read route %s (%u -> %u)", LOG_ENTRY_ARGS (i, entry),
vtable->vt->route_to_string (&entry->route), (guint) entry->effective_metric,
(guint) entry->effective_metric);
}
@@ -1227,10 +1227,10 @@ _resync_idle_reschedule (NMDefaultRouteManager *self)
{
NMDefaultRouteManagerPrivate *priv = NM_DEFAULT_ROUTE_MANAGER_GET_PRIVATE (self);
/* since we react on external changes and readd/remove default routes for
* the interfaces we manage, there could be the erronous situation where two applications
* fight over a certain default route.
- * Avoid this, by increasingly wait longer to touch the system (backoff wait time). */
+ * Avoid this, by increasingly wait longer to touch tehe system (backoff wait time). */
if (priv->resync.backoff_wait_time_ms == 0) {
/* for scheduling idle, always reschedule (to process all other events first) */
@@ -1227,10 +1227,10 @@ _resync_idle_reschedule (NMDefaultRouteManager *self)
{
NMDefaultRouteManagerPrivate *priv = NM_DEFAULT_ROUTE_MANAGER_GET_PRIVATE (self);
- /* since we react on external changes and readd/remove default routes for
- * the interfaces we manage, there could be the erronous situation where two applications
+ /* since we react on external changes and read/remove default routes for
+ * the interfaces we manage, there could be the erroneous situation where two applications
* fight over a certain default route.